@@ -4,7 +4,7 @@ Main interface for logs service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_logs import (
         Client,
         CloudWatchLogsClient,
@@ -19,10 +19,8 @@ Usage::
         FilterLogEventsPaginator,
     )
 
-    session = boto3.Session()
-
-    client: CloudWatchLogsClient = boto3.client("logs")
-    session_client: CloudWatchLogsClient = session.client("logs")
+    session = Session()
+    client: CloudWatchLogsClient = session.client("logs")
 
     describe_destinations_paginator: DescribeDestinationsPaginator = client.get_paginator("describe_destinations")
     describe_export_tasks_paginator: DescribeExportTasksPaginator = client.get_paginator("describe_export_tasks")
